# =====================================
# generator=datazen
# version=3.1.0
# hash=dafe84a6e5142926fa20f9461451e0b6
# =====================================

"""
Useful defaults and other package metadata.
"""

DESCRIPTION = "A configuration-file management system."
PKG_NAME = "rcmpy"
VERSION = "0.1.0"
